function g = vario_fun(h,fun,p)

% vario_fun - variogram model functions 
% -------------------------------------
%
% g = vario_fun(h,fun,p)
%
% Input:
% ------
%  h - distance grid
%  fun - model
%    'exp' - exponential
%    'gauss' - gaussian
%    'lin' - linear
%    'sph' - spherical
%  p - model parameters
